# Specs for core of plant
module Plant
  RSpec.describe Core do
    before :each do
      Plant::Content.delete_all
    end

    it 'should be able to create new content' do
      expect(Content.new).to be_a Plant::Content
    end

    it 'should create a factory' do
      expect(create(:content)).to be_a Plant::Content
    end

    it 'should be able to find on a node' do
      create :content, node_id: 'foobar', content: 'Harrah'
      result = Plant::Content.get_node_content('foobar')
      expect(result).to eq('Harrah')
    end

    it 'should only allow one entry for node-id/scenario combination' do
      create :content, node_id: 'jump'
      create :content, node_id: 'jump.no'
      create :content, node_id: 'jump.yes'
      cont = build(:content, node_id: 'jump.no')
      expect(cont).to_not be_valid
    end

    it 'should find a node' do
      node = create :content, node_id: 'milk'
      result = Plant::Content.get_node('milk')
      expect(result).to eq(node)
    end

    it 'should replace parameters' do
      create :content, node_id: 'pirates', content: 'Say arrrr to #{name}'
      result = Plant::Content.get_node_content('pirates', name: 'Harry')
      expect(result).to eq('Say arrrr to Harry')
    end

    it 'should multi inject params' do
      create :content, node_id: 'pirates',
                       content: 'Say arrrr to #{name} the #{animal}'
      result = Plant::Content.get_node_content('pirates',
                                               name: 'Harry',
                                               animal: 'dog')
      expect(result).to eq('Say arrrr to Harry the dog')
    end

    context 'with scenarios' do
      before :each do
        create :content, node_id: 'foo', content: 'ice cream'
        @lollipop = create :content, node_id: 'foo.mm', content: 'lollipop'
      end

      it 'should find a node with a scenario' do
        result = Plant::Content.get_node_content('foo', 'mm')
        expect(result).to eq('lollipop')
      end

      it 'can find node object with scenario' do
        result = Plant::Content.get_node('foo', scenario: 'mm')
        expect(result).to eq(@lollipop)
      end

      it 'should find a node without a scenario' do
        result = Plant::Content.get_node_content('foo')
        expect(result).to eq('ice cream')
      end

      it 'should find a node with an object scenario' do
        user = double(scenario: 'mm')
        result = Plant::Content.get_node_content('foo', user)
        expect(result).to eq('lollipop')
      end

      it 'should throw when nothing found' do
        expect do
          Plant::Content.get_node_content('NODDY')
        end.to raise_exception(ActiveRecord::RecordNotFound)
      end
    end
  end
end
