require 'rake'
RSpec.describe 'Populating the database' do
  before :all do
    Plant::Content.delete_all
    Rake.application.rake_require 'tasks/plant_tasks'
    Rake::Task.define_task(:environment)
    Rake::Task['plant:seed'].reenable
    Rake.application.invoke_task 'plant:seed'
  end

  after :all do
    Plant::Content.delete_all
  end

  it 'should be able to get the moon name' do
    cont = Plant::Content.get_node_content('jupiter.io.moon_name')
    expect(cont).to eq('Foobar')
  end

  it 'should be able to get the moon name on Tuesdays' do
    cont = Plant::Content.get_node_content('jupiter.io.moon_name.tuesdays')
    expect(cont).to eq('Barfoo')
  end

  it 'should be able to get the moon name on Wednesdays' do
    cont = Plant::Content.get_node_content('jupiter.io.moon_name.wednesdays')
    expect(cont).to eq('multi line content with some stuff')
  end
end

RSpec.describe 'Populating just one file' do
  before :all do
    Plant::Content.delete_all
    Rake.application.rake_require 'tasks/plant_tasks'
    Rake::Task.define_task(:environment)
    Rake::Task['plant:specific_seed'].reenable
    Rake.application.invoke_task 'plant:specific_seed[spec/support/test.yml]'
  end

  after :all do
    Plant::Content.delete_all
  end

  it 'should get the one file' do
    plant = Plant::Content.first
    expect(Plant::Content.count).to eq(1)
    expect(plant.node_id).to eq('foo.mm.nn')
  end
end
